pub struct RecentSelfPaths {
inner: Mutex<HashMap<String, Instant>>,
}Expand description
TTL’d set of paths Mimick itself just modified, used to suppress the filesystem events those modifications cause.
Fields
inner: Mutex<HashMap<String, Instant>>Mutex-wrapped map of self-modified paths to the instant they were modified.
Implementations