pub(crate) fn open_library_window_now(app: &Application, ctx: Arc<AppContext>)Expand description
Open Library window, falling back to Settings if disabled.
pub(crate) fn open_library_window_now(app: &Application, ctx: Arc<AppContext>)Open Library window, falling back to Settings if disabled.