fn album_tile(
ctx: Arc<AppContext>,
album: &LibraryAlbum,
on_click: Rc<dyn Fn(&str, String)>,
) -> ButtonExpand description
Build a clickable tile representing an individual album complete with cover art.
fn album_tile(
ctx: Arc<AppContext>,
album: &LibraryAlbum,
on_click: Rc<dyn Fn(&str, String)>,
) -> ButtonBuild a clickable tile representing an individual album complete with cover art.