pub fn populate_albums(
parts: &AlbumsViewParts,
ctx: Arc<AppContext>,
albums: Vec<LibraryAlbum>,
on_click: Rc<dyn Fn(&str, String)>,
)Expand description
Populate the album list grids grouped by ownership status.
pub fn populate_albums(
parts: &AlbumsViewParts,
ctx: Arc<AppContext>,
albums: Vec<LibraryAlbum>,
on_click: Rc<dyn Fn(&str, String)>,
)Populate the album list grids grouped by ownership status.