fn spawn_thumbnail(ctx: Arc<AppContext>, asset_id: String, picture: Picture)Expand description
Asynchronously load and set the thumbnail for an album cover art picture widget.
fn spawn_thumbnail(ctx: Arc<AppContext>, asset_id: String, picture: Picture)Asynchronously load and set the thumbnail for an album cover art picture widget.