fn spawn_asset_thumbnail(
ctx: Arc<AppContext>,
asset_id: String,
picture: Picture,
)Expand description
Helper to asynchronously request and bind an asset cover art thumbnail image.
fn spawn_asset_thumbnail(
ctx: Arc<AppContext>,
asset_id: String,
picture: Picture,
)Helper to asynchronously request and bind an asset cover art thumbnail image.