fn spawn_person_thumbnail(
ctx: Arc<AppContext>,
person_id: String,
picture: Picture,
)Expand description
Helper to asynchronously request and render a round avatar person face thumbnail.
fn spawn_person_thumbnail(
ctx: Arc<AppContext>,
person_id: String,
picture: Picture,
)Helper to asynchronously request and render a round avatar person face thumbnail.