fn apply_timeline_ui_state(ui: &LibraryWindowUi, source: &LibrarySource)Expand description
Apply header control layout adjustments when switching view modes.
fn apply_timeline_ui_state(ui: &LibraryWindowUi, source: &LibrarySource)Apply header control layout adjustments when switching view modes.