fn bootstrap_window(ui: Rc<LibraryWindowUi>)Expand description
Bootstrap initial data loading and background tasks for the library window.
fn bootstrap_window(ui: Rc<LibraryWindowUi>)Bootstrap initial data loading and background tasks for the library window.