build_drop_overlay

Function build_drop_overlay 

fn build_drop_overlay(content: Box) -> (Overlay, Revealer)
Build a drop overlay widget and wrap content in a gtk::Overlay.

Returns the overlay wrapper (to be used as the content widget) and the revealer handle for toggling visibility from the DropTarget handlers.