fn dispatch_search_from_view(ui: &Rc<LibraryWindowUi>)Expand description
Read the search view widgets and dispatch the appropriate search source.
fn dispatch_search_from_view(ui: &Rc<LibraryWindowUi>)Read the search view widgets and dispatch the appropriate search source.