linked_entry_path_for_album

Function linked_entry_path_for_album 

fn linked_entry_path_for_album(
    ui: &Rc<LibraryWindowUi>,
    album_name: &str,
) -> Option<String>
Return the path of the watch entry linked to album_name, if any. Find the local directory watch path mapped to the specified album.