fn load_source_page(
ui: Rc<LibraryWindowUi>,
request: (u64, LibrarySource, u32),
append: bool,
)Expand description
Load a paginated subset of assets for the current source.
fn load_source_page(
ui: Rc<LibraryWindowUi>,
request: (u64, LibrarySource, u32),
append: bool,
)Load a paginated subset of assets for the current source.