load_texture_oriented

Function load_texture_oriented 

pub(crate) async fn load_texture_oriented(path: &Path) -> Option<Texture>
Load a local texture, preferring decoders that cover formats outside the GDK-Pixbuf runtime loader set before falling back to pixbuf and image-rs.