fn prompt_create_album(ui: Rc<LibraryWindowUi>)Expand description
Show a popup modal dialog prompting the user to name and create a new album.
fn prompt_create_album(ui: Rc<LibraryWindowUi>)Show a popup modal dialog prompting the user to name and create a new album.