fn spawn_transfer_poll_loop(ui: Rc<LibraryWindowUi>)Expand description
Start a quick periodic polling loop updating the transfer progress bar UI.
fn spawn_transfer_poll_loop(ui: Rc<LibraryWindowUi>)Start a quick periodic polling loop updating the transfer progress bar UI.