fn update_footer(ui: &LibraryWindowUi, route: Option<String>)Expand description
Update the status sidebar rows with the current server route and statistics.
fn update_footer(ui: &LibraryWindowUi, route: Option<String>)Update the status sidebar rows with the current server route and statistics.