fn update_timeline_banner_if_active(ui: &Rc<LibraryWindowUi>, adj: &Adjustment)Expand description
Compute and refresh the month-year overlay text dynamically while scrubbing the timeline list.
fn update_timeline_banner_if_active(ui: &Rc<LibraryWindowUi>, adj: &Adjustment)Compute and refresh the month-year overlay text dynamically while scrubbing the timeline list.