pub(super) fn open_lightbox(ui: Rc<LibraryWindowUi>, position: u32)Expand description
Construct and present the fullscreen lightbox view for a selected asset.
pub(super) fn open_lightbox(ui: Rc<LibraryWindowUi>, position: u32)Construct and present the fullscreen lightbox view for a selected asset.