pub(crate) fn fallback_bucket(size: ThumbnailSize) -> Option<ThumbnailSize>Expand description
Smaller size to try when a requested bucket isn’t available on the server.
pub(crate) fn fallback_bucket(size: ThumbnailSize) -> Option<ThumbnailSize>Smaller size to try when a requested bucket isn’t available on the server.