fn build_staging_assets(files: &[PathBuf]) -> Vec<AssetObject>Expand description
Build AssetObject entries from local file paths for the staging grid.
fn build_staging_assets(files: &[PathBuf]) -> Vec<AssetObject>Build AssetObject entries from local file paths for the staging grid.