fn build_staging_ui(
window: &ApplicationWindow,
ctx: &Arc<AppContext>,
files: &[PathBuf],
) -> (Button, Button, Button, GridViewParts, Label)Expand description
Build header, grid, toolbar, status bar and return the interactive widgets.
fn build_staging_ui(
window: &ApplicationWindow,
ctx: &Arc<AppContext>,
files: &[PathBuf],
) -> (Button, Button, Button, GridViewParts, Label)Build header, grid, toolbar, status bar and return the interactive widgets.