build_staging_window

Function build_staging_window 

pub fn build_staging_window(
    app: &Application,
    ctx: Arc<AppContext>,
    files: Vec<PathBuf>,
    auto_upload: bool,
)
Build and present the staging window populated with the given file paths.

When auto_upload is true (the --upload Desktop Action), an album picker dialog is presented immediately after the window opens.