pub(crate) fn show_album_picker(
parent: ApplicationWindow,
ctx: Arc<AppContext>,
paths: Vec<PathBuf>,
)Expand description
Present an album picker dialog and upload files to the chosen album.
pub(crate) fn show_album_picker(
parent: ApplicationWindow,
ctx: Arc<AppContext>,
paths: Vec<PathBuf>,
)Present an album picker dialog and upload files to the chosen album.