struct SizedLruCache {
inner: LruCache<String, Texture>,
current_bytes: usize,
max_bytes: usize,
evictions_since_log: usize,
}Expand description
LRU Cache that limits memory usage based on estimated byte size.
Fields
inner: LruCache<String, Texture>current_bytes: usizemax_bytes: usizeevictions_since_log: usizeImplementations
Sourceimpl SizedLruCache
impl SizedLruCache
fn stats(&mut self) -> (usize, usize, usize, usize)
Sourcefn get(&mut self, key: &str) -> Option<Texture>
fn get(&mut self, key: &str) -> Option<Texture>
Retrieve a texture from the cache if present, updating LRU recency.
fn peek(&self, key: &str) -> Option<Texture>