fn replace_watches(
watcher: &mut dyn Watcher,
watched_roots: &mut Vec<PathBuf>,
watch_paths: &[WatchPathEntry],
background_sync_enabled: bool,
)Expand description
Replace live directories being monitored by the given watcher.
fn replace_watches(
watcher: &mut dyn Watcher,
watched_roots: &mut Vec<PathBuf>,
watch_paths: &[WatchPathEntry],
background_sync_enabled: bool,
)Replace live directories being monitored by the given watcher.