send_sync_summary

Function send_sync_summary 

pub fn send_sync_summary(succeeded: usize, failed: usize)
Fired once when the upload queue drains after an active sync cycle.

succeeded and failed are the counts for that sync cycle.