pub struct EnvironmentPolicy {
pub pause_on_metered_network: bool,
pub pause_on_battery_power: bool,
pub quiet_hours_start: Option<u8>,
pub quiet_hours_end: Option<u8>,
}Fields
pause_on_metered_network: boolTrue if syncing should pause when metered connections are detected.
pause_on_battery_power: boolTrue if syncing should pause when battery power is detected.
quiet_hours_start: Option<u8>First local clock hour (0–23) of the quiet window. None = disabled.
quiet_hours_end: Option<u8>Last local clock hour (0–23, exclusive) of the quiet window.