pub async fn build_local_deletion_request(
ctx: Arc<AppContext>,
path: String,
) -> Option<LocalDeletionRequest>Expand description
Check if local deletion matches validation criteria for remote mirror sweep.
pub async fn build_local_deletion_request(
ctx: Arc<AppContext>,
path: String,
) -> Option<LocalDeletionRequest>Check if local deletion matches validation criteria for remote mirror sweep.