pub fn build_settings_window(app: &Application, ctx: Arc<AppContext>)Expand description
Construct and present the settings window as a top-level window.
pub fn build_settings_window(app: &Application, ctx: Arc<AppContext>)Construct and present the settings window as a top-level window.