pub fn build_settings_window_with_parent(
app: &Application,
ctx: Arc<AppContext>,
parent: Option<&ApplicationWindow>,
)Expand description
Construct and present the settings window, optionally transient for a parent window.
pub fn build_settings_window_with_parent(
app: &Application,
ctx: Arc<AppContext>,
parent: Option<&ApplicationWindow>,
)Construct and present the settings window, optionally transient for a parent window.