pub(super) fn show_about_dialog(parent: &impl IsA<Widget>)Expand description
Construct and present the Libadwaita standard About Dialog for the application.
pub(super) fn show_about_dialog(parent: &impl IsA<Widget>)Construct and present the Libadwaita standard About Dialog for the application.