fn effective_album_name(entry: &WatchPathEntry, path: &Path) -> StringExpand description
Resolve the effective album name for a file using per-folder configuration.
fn effective_album_name(entry: &WatchPathEntry, path: &Path) -> StringResolve the effective album name for a file using per-folder configuration.