async fn sync_album_to_folder_entries(
watch_paths: &[WatchPathEntry],
app_ctx: Arc<AppContext>,
)Expand description
Parallel reconcile for each watch path entry against their remote albums.
async fn sync_album_to_folder_entries(
watch_paths: &[WatchPathEntry],
app_ctx: Arc<AppContext>,
)Parallel reconcile for each watch path entry against their remote albums.