trash_remote_asset_by_checksum

Function trash_remote_asset_by_checksum 

async fn trash_remote_asset_by_checksum(
    api_client: &ImmichApiClient,
    sync_index: &ShardedSyncIndex,
    local_path: &str,
    album_id: &str,
    checksum: &str,
    album_name: &str,
) -> bool
Locate and move a remote asset to Immich trash by looking up its checksum in an album.