TransferSnapshot

Struct TransferSnapshot 

pub struct TransferSnapshot {
Show 22 fields pub active: bool, pub direction: TransferDirection, pub current_bytes: u64, pub total_bytes: Option<u64>, pub session_total_bytes: u64, pub session_transferred_bytes: u64, pub completed_total_bytes: u64, pub completed_transferred_bytes: u64, pub instant_bps: f64, pub session_avg_bps: f64, pub session_started_at: Option<f64>, pub session_bytes_done: u64, pub active_item_label: Option<String>, pub active_route: Option<String>, pub last_upload_avg_bps: f64, pub last_download_avg_bps: f64, pub last_tick_at: Option<f64>, pub last_tick_bytes: u64, pub active_uploads: usize, pub active_downloads: usize, pub active_item_bytes: HashMap<String, u64>, pub active_item_totals: HashMap<String, u64>,
}
Snapshot describing currently executing and active file transfers.

Fields

active: bool

True if a transfer batch session is currently running.

direction: TransferDirection

Direction of current active transfer session.

current_bytes: u64

Total bytes processed in current transfer task.

total_bytes: Option<u64>

Total bytes target across current session.

session_total_bytes: u64

Estimated sum of all item file sizes in the active batch.

session_transferred_bytes: u64

Sum of all bytes successfully sent or received in this session.

completed_total_bytes: u64

Total target bytes of previously finished items in the batch.

completed_transferred_bytes: u64

Total bytes completed of previously finished items in the batch.

instant_bps: f64

Instant speed in bytes per second.

session_avg_bps: f64

Average session speed in bytes per second.

session_started_at: Option<f64>

Epoch timestamp when the transfer session was started.

session_bytes_done: u64

Snapshot count of completed session bytes.

active_item_label: Option<String>

Label representing the file currently being processed.

active_route: Option<String>

Active network route segment used for connection.

last_upload_avg_bps: f64

Average bytes per second achieved on the last upload batch.

last_download_avg_bps: f64

Average bytes per second achieved on the last download batch.

last_tick_at: Option<f64>

Tick epoch timestamp used to recalculate instant speed.

last_tick_bytes: u64

Bytes processed on the last instant speed tick check.

active_uploads: usize

Number of active parallel upload workers.

active_downloads: usize

Number of active parallel download workers.

active_item_bytes: HashMap<String, u64>

Track of active item transferred bytes maps.

active_item_totals: HashMap<String, u64>

Track of active item total sizes maps.

Implementations

Source

impl TransferSnapshot

pub fn reset_runtime(&mut self)

Reset active metrics back to zero.

fn should_switch_to(&self, direction: &TransferDirection) -> bool

Check if target transfer direction should be switched.

fn ensure_session( &mut self, direction: TransferDirection, route: Option<String>, )

Ensure an active transfer session group is initialized.

pub fn register_item( &mut self, direction: TransferDirection, item_id: impl Into<String>, total_bytes: Option<u64>, item_label: Option<String>, route: Option<String>, )

Add an active item structure into the ongoing transfer snapshot.

pub fn begin_group( &mut self, direction: TransferDirection, item_label: Option<String>, route: Option<String>, )

Start tracking a group of transfer operations.

pub fn update_item_total(&mut self, item_id: &str, total_bytes: u64)

Update total sizes for a specific active item in the transfer.

pub fn update_item_bytes( &mut self, direction: TransferDirection, item_id: &str, bytes_done: u64, route: Option<String>, )

Update bytes completed so far for a specific active item.

pub fn finish_item( &mut self, direction: TransferDirection, item_id: &str, route: Option<String>, ) -> bool

Finish tracking a specific item, returning true if the session is empty.