fn load_entries(index_file: &Path) -> HashMap<String, SyncedFileRecord>Expand description
Helper to load all stored sync records from the file.
fn load_entries(index_file: &Path) -> HashMap<String, SyncedFileRecord>Helper to load all stored sync records from the file.