pub async fn build_tray(
library_view_enabled: bool,
) -> Result<TrayHandles, Error>Expand description
Asynchronously construct and spawn the system tray icon, returning control channels.
pub async fn build_tray(
library_view_enabled: bool,
) -> Result<TrayHandles, Error>Asynchronously construct and spawn the system tray icon, returning control channels.