fn linked_entry_path_for_album(
ui: &Rc<LibraryWindowUi>,
album_name: &str,
) -> Option<String>Expand description
Return the path of the watch entry linked to album_name, if any.
Find the local directory watch path mapped to the specified album.