pub(super) fn show_album_picker_dialog(
parent: &impl IsA<Window>,
albums_ref: Rc<RefCell<Vec<(String, String)>>>,
target_album_state: Rc<RefCell<String>>,
trigger_btn: Button,
on_settings_changed: Rc<dyn Fn()>,
)Expand description
Construct and present a modal search and select window for linking a folder to an Immich album.