pub fn display_watch_path_inline(path: &str) -> StringExpand description
Returns the full path for regular folders, or the folder name for Flatpak portal paths. Useful for contexts where the path is displayed inline (e.g., diagnostics, album linked folder) without a separate subtitle.